@@ -1,7 +1,7 @@
 
 from typing import Any
 
-import requests
+from curl_cffi import requests
 from loguru import logger
 
 
@@ -133,7 +133,7 @@ class BaseCracker:
                 "user-agent",
             ] and self._extra_data.get(k):
                 headers[k] = self._extra_data[k]            
-    
+
     def crack(self):
         headers = {
             "User-Token": self.user_token
