@@ -28,7 +28,7 @@ class CloudFlareCracker(BaseCracker):
     """
     
     # 必传参数
-    must_check_params = ["href", "proxy"]
+    must_check_params = ["href"]
     # 默认可选参数
     option_params = {
         "branch": "Master",
